pub enum Error {
AlreadySet(SetLoggerError),
Io(Error),
TlsHandshake(HandshakeError<TcpStream>),
Tls(Error),
}Expand description
Errors that can occur when using this crate.
Variants
AlreadySet(SetLoggerError)
Occurs when trying to set the logger while another one is already set.
Io(Error)
Occurs when any open, write or flush calls fail.
TlsHandshake(HandshakeError<TcpStream>)
Occurs when the TLS handshake fails.
Tls(Error)
Occurs when any TLS error happen.